package logic

import (
	"fusenapi/constants"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"math"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetDepartmentsLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetDepartmentsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetDepartmentsLogic {
	return &GetDepartmentsLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *GetDepartmentsLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *GetDepartmentsLogic) GetDepartments(req *types.GetDepartmentsReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	//todo 鉴权 。。。。
	if req.CurrentPage <= 0{
		req.CurrentPage = constants.DEFAULT_PAGE
	}
	if req.Limit <= 0{
		req.Limit = constants.DEFAULT_PAGE_SIZE
	}
	departList,total,err := l.svcCtx.AllModels.LdapDepartment.GetList(l.ctx,req.CurrentPage,req.Limit,"")
	if err != nil{
		logx.Error(err)
		return resp.SetStatusWithMessage(basic.CodeDbSqlErr,"获取部门列表失败")
	}
	list := make([]types.DepartmentsItem,0,len(departList))
	for _,v := range departList{
		list = append(list,types.DepartmentsItem{
			Id:       v.Id,
			Name:     *v.Name,
			Remark:   *v.Remark,
			Type:     *v.Type,
			ParentId: *v.ParentId,
			Dn:       *v.Dn,
			SyncState: *v.SyncState,
		})
	}
	return resp.SetStatus(basic.CodeOK,"success",types.GetDepartmentsRsp{
		List: list,
		Meta: types.Meta{
			TotalCount:  total,
			PageCount:   int64(math.Ceil(float64(total) / float64(req.Limit))),
			CurrentPage: req.CurrentPage,
			PerPage:     req.Limit,
		},
	})
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *GetDepartmentsLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
